summaryrefslogtreecommitdiff
path: root/examples/ibb_transfer/ibb_receiver.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/ibb_transfer/ibb_receiver.py')
-rwxr-xr-xexamples/ibb_transfer/ibb_receiver.py135
1 files changed, 50 insertions, 85 deletions
diff --git a/examples/ibb_transfer/ibb_receiver.py b/examples/ibb_transfer/ibb_receiver.py
index 6aba98e3..e934f295 100755
--- a/examples/ibb_transfer/ibb_receiver.py
+++ b/examples/ibb_transfer/ibb_receiver.py
@@ -1,45 +1,31 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
-import sys
import logging
-import getpass
-from optparse import OptionParser
+from getpass import getpass
+from argparse import ArgumentParser
-import sleekxmpp
+import slixmpp
-# Python versions before 3.0 do not use UTF-8 encoding
-# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
-# ourselves to UTF-8.
-if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
- setdefaultencoding('utf8')
-else:
- raw_input = input
-
-class IBBReceiver(sleekxmpp.ClientXMPP):
+class IBBReceiver(slixmpp.ClientXMPP):
"""
A basic example of creating and using an in-band bytestream.
"""
- def __init__(self, jid, password):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ def __init__(self, jid, password, filename):
+ slixmpp.ClientXMPP.__init__(self, jid, password)
- self.register_plugin('xep_0030') # Service Discovery
- self.register_plugin('xep_0047', {
- 'auto_accept': True
- }) # In-band Bytestreams
+ self.file = open(filename, 'wb')
# The session_start event will be triggered when
# the bot establishes its connection with the server
@@ -48,8 +34,9 @@ class IBBReceiver(sleekxmpp.ClientXMPP):
# our roster.
self.add_event_handler("session_start", self.start)
- self.add_event_handler("ibb_stream_start", self.stream_opened, threaded=True)
+ self.add_event_handler("ibb_stream_start", self.stream_opened)
self.add_event_handler("ibb_stream_data", self.stream_data)
+ self.add_event_handler("ibb_stream_end", self.stream_closed)
def start(self, event):
"""
@@ -67,81 +54,59 @@ class IBBReceiver(sleekxmpp.ClientXMPP):
self.send_presence()
self.get_roster()
- def accept_stream(self, iq):
- """
- Check that it is ok to accept a stream request.
-
- Controlling stream acceptance can be done via either:
- - setting 'auto_accept' to False in the plugin
- configuration. The default is True.
- - setting 'accept_stream' to a function which accepts
- an Iq stanza as its argument, like this one.
-
- The accept_stream function will be used if it exists, and the
- auto_accept value will be used otherwise.
- """
- return True
-
def stream_opened(self, stream):
print('Stream opened: %s from %s' % (stream.sid, stream.peer_jid))
- # You could run a loop reading from the stream using stream.recv(),
- # or use the ibb_stream_data event.
+ def stream_data(self, stream):
+ self.file.write(stream.read())
- def stream_data(self, event):
- print(event['data'])
+ def stream_closed(self, stream):
+ print('Stream closed: %s from %s' % (stream.sid, stream.peer_jid))
+ self.file.close()
+ self.disconnect()
if __name__ == '__main__':
# Setup the command line arguments.
- optp = OptionParser()
+ parser = ArgumentParser()
# Output verbosity options.
- optp.add_option('-q', '--quiet', help='set logging to ERROR',
- action='store_const', dest='loglevel',
- const=logging.ERROR, default=logging.INFO)
- optp.add_option('-d', '--debug', help='set logging to DEBUG',
- action='store_const', dest='loglevel',
- const=logging.DEBUG, default=logging.INFO)
- optp.add_option('-v', '--verbose', help='set logging to COMM',
- action='store_const', dest='loglevel',
- const=5, default=logging.INFO)
+ parser.add_argument("-q", "--quiet", help="set logging to ERROR",
+ action="store_const", dest="loglevel",
+ const=logging.ERROR, default=logging.INFO)
+ parser.add_argument("-d", "--debug", help="set logging to DEBUG",
+ action="store_const", dest="loglevel",
+ const=logging.DEBUG, default=logging.INFO)
# JID and password options.
- optp.add_option("-j", "--jid", dest="jid",
- help="JID to use")
- optp.add_option("-p", "--password", dest="password",
- help="password to use")
+ parser.add_argument("-j", "--jid", dest="jid",
+ help="JID to use")
+ parser.add_argument("-p", "--password", dest="password",
+ help="password to use")
+ parser.add_argument("-o", "--out", dest="filename",
+ help="file to save to")
- opts, args = optp.parse_args()
+ args = parser.parse_args()
# Setup logging.
- logging.basicConfig(level=opts.loglevel,
+ logging.basicConfig(level=args.loglevel,
format='%(levelname)-8s %(message)s')
- if opts.jid is None:
- opts.jid = raw_input("Username: ")
- if opts.password is None:
- opts.password = getpass.getpass("Password: ")
-
- xmpp = IBBReceiver(opts.jid, opts.password)
-
- # If you are working with an OpenFire server, you may need
- # to adjust the SSL version used:
- # xmpp.ssl_version = ssl.PROTOCOL_SSLv3
-
- # If you want to verify the SSL certificates offered by a server:
- # xmpp.ca_certs = "path/to/ca/cert"
+ if args.jid is None:
+ args.jid = input("Username: ")
+ if args.password is None:
+ args.password = getpass("Password: ")
+ if args.filename is None:
+ args.filename = input("File path: ")
+
+ # Setup the IBBReceiver and register plugins. Note that while plugins may
+ # have interdependencies, the order in which you register them does
+ # not matter.
+ xmpp = IBBReceiver(args.jid, args.password, args.filename)
+ xmpp.register_plugin('xep_0030') # Service Discovery
+ xmpp.register_plugin('xep_0047', {
+ 'auto_accept': True
+ }) # In-band Bytestreams
# Connect to the XMPP server and start processing XMPP stanzas.
- if xmpp.connect():
- # If you do not have the dnspython library installed, you will need
- # to manually specify the name of the server if it does not match
- # the one in the JID. For example, to use Google Talk you would
- # need to use:
- #
- # if xmpp.connect(('talk.google.com', 5222)):
- # ...
- xmpp.process(block=True)
- print("Done")
- else:
- print("Unable to connect.")
+ xmpp.connect()
+ xmpp.process(forever=False)
@@ -1,45 +1,31 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz